@@ -1,10 +1,9 @@
 import os
 import json
-from pathlib import Path
+import logging
 from collections import OrderedDict
 from Accuinsight.modeler.core.Run.RunOjbject import RunObject
 from Accuinsight.modeler.core.LcConst import LcConst
-from Accuinsight.modeler.utils.os_getenv import is_in_ipython
 
 # RUN_MODEL_HDF5_PATH, RUN_RESULT_PATH,
 # RUN_MODEL_JSON_PATH, RUN_MODEL_VISUAL_CSV_PATH, RUN_MODEL_VISUAL_JSON_PATH,
@@ -42,14 +41,8 @@ def set_current_runs(run_name):
 
 
 def get_current_run():
-    save_path = str(Path.home()) + LcConst.RUN_ROOT_PATH + 'run_info.json'
-    if is_in_ipython():
-        save_path = LcConst.ENV_JUPYTER_HOME_DIR + LcConst.RUN_ROOT_PATH + 'run_info.json'
-
-    with open(save_path) as json_file:
-        json_data = json.load(json_file)
- 
-    return json_data
+    with open(LcConst.ENV_JUPYTER_HOME_DIR + LcConst.RUN_ROOT_PATH + 'run_info.json') as json_file:
+        return json.load(json_file)
 
 
 def _get_run_data_value_by_key():
@@ -208,16 +201,14 @@ def set_best_model_joblib_path(joblib_path=None):
 
 
 def get_or_create_run_directory():
-    is_notebook = is_in_ipython()
-    run_dir = str(Path.home()) + LcConst.RUN_ROOT_PATH
-    if is_notebook:
-        run_dir = LcConst.ENV_JUPYTER_HOME_DIR + LcConst.RUN_ROOT_PATH
+    run_dir = LcConst.ENV_JUPYTER_HOME_DIR + LcConst.RUN_ROOT_PATH
 
     if not os.path.isdir(run_dir):
         try:
             os.mkdir(run_dir)
         except:
-            pass
+            logging.info("Run directory is not created")
+
     return run_dir
 
 
